Skip to contents

Initialize gsm Extension package

Usage

init_gsm_package(
  strPackageDir,
  lDescriptionFields = list(),
  bIncludeWorkflowDir = TRUE,
  strOrg = "Gilead-BioStats"
)

Arguments

strPackageDir

(string) Path to the package directory.

lDescriptionFields

(list) Description fields, passed to usethis::create_package(). Default is list().

bIncludeWorkflowDir

(boolean) Whether or not to include the inst/workflow directory in the root of the package. Default is TRUE.

strOrg

(string) GitHub organization under which the repo should be created. Set to NULL to create the package in your personal GitHub account.