Skip to contents

Rmarkdown render function that defaults to rendering intermediate Rmd files in a temporary directory, and falls back to a writable output directory when needed.

Usage

render_rmd(
  strInputPath,
  strOutputFile = basename(strInputPath),
  strOutputDir = getwd(),
  lParams = NULL,
  quiet = FALSE
)

Arguments

strInputPath

(string) Path to the template Rmd file.

strOutputFile

(string) Filename for the output.

strOutputDir

(string) Path to the directory where the output will be saved.

lParams

(list) Parameters to pass to the template Rmd file.

quiet

(boolean) Passed to rmarkdown::render().

Value

Rendered Rmarkdown file path (invisibly).