Add an official Gilead GitHub Action to a package, or update an existing
Gilead GitHub Action to the latest version if necessary. The source location
is determined by the manifest fields repo, ref, and path_extra.
Usage
add_action(
name,
version,
repo,
ref,
...,
path_extra = NULL,
workflows_path = "./.github/workflows",
overwrite = TRUE,
verbose = TRUE
)Arguments
- name
(
string) The action to install.- version
(
string) The expected version of the action.- repo
(
string) GitHub repository inowner/repoform.- ref
(
string) Git ref (branch, tag, or SHA) inrepo.- ...
These dots are for future extensions and must be empty.
- path_extra
(
stringorNULL) Optional subdirectory within the ref where the workflow file lives.- workflows_path
(
string) Path to the package workflows.- overwrite
(
boolean) Overwrite existing files? Default isTRUE.- verbose
(
boolean) Inform about changes? Default isTRUE.