Scan a directory for subdirectories, render any .*md files in those
subdirectories to .html, and add them to the pkgdown index.
Usage
build_assets(
source_dir = "pkgdown/menus",
assets_dir = "pkgdown/assets",
pkgdown_yml = "_pkgdown.yml",
root_dir = ".",
verbose = FALSE
)Arguments
- source_dir
(
string) Path to the directory containing subdirectories with.*mdfiles to render. Default is"pkgdown/menus".- assets_dir
(
string) Path to the directory where rendered.htmlfiles should be saved. Default is"pkgdown/assets".- pkgdown_yml
(
string) Path to the_pkgdown.ymlfile to update with new menu items, or from which to remove unused menu items.- root_dir
(
string) Path to the root directory of the package, used to construct absolute paths. Default is".".- verbose
(
boolean) Inform about changes? Default isTRUE.