Rmarkdown render function that defaults to rendering intermediate Rmd files in a temporary directory, and falls back to a writable output directory when needed.
Arguments
- strInputPath
(
string) Path to the templateRmdfile.- strOutputFile
(
string) Filename for the output.- strOutputDir
(
string) Path to the directory where the output will be saved.- lParams
(
list) Parameters to pass to the templateRmdfile.- quiet
(
boolean) Passed tormarkdown::render().