Rmarkdown render function that defaults to rendering intermediate Rmd files in a temporary directory, and falls back to a writable output directory when needed.
Arguments
- strInputPath
stringorfs_pathPath to the templateRmdfile.- strOutputFile
stringFilename for the output.- strOutputDir
stringorfs_pathPath to the directory where the output will be saved.- lParams
listParameters to pass to the templateRmdfile.- quiet
Logical. Passed to
rmarkdown::render().